import unittest
import unittest.mock as mock

from reactive import bcache_tuning  # noqa: E402


class TestBcacheTuning(unittest.TestCase):
    def setUp(self):
        super(TestBcacheTuning, self).setUp()

    @mock.patch("shutil.copyfile")
    @mock.patch("os.chmod")
    @mock.patch("subprocess.check_call")
    @mock.patch.object(bcache_tuning, "set_flag")
    def test_install_bcache_tuning(
        self, mock_set_flag, mock_check_call, mock_chmod, mock_copyfile
    ):
        tune_bcache_bin = "/usr/local/bin/tune-bcache"
        bcache_tuning.install_bcache_tuning()
        copyfile_calls = [
            mock.call("files/tune-bcache", tune_bcache_bin),
            mock.call(
                "files/tune-bcache.service", "/lib/systemd/system/tune-bcache.service"
            ),
        ]
        chmod_calls = [mock.call(tune_bcache_bin, 0o755)]
        checkcall_calls = [
            mock.call(["systemctl", "daemon-reload"]),
            mock.call(["systemctl", "enable", "tune-bcache.service"]),
            mock.call(["systemctl", "start", "tune-bcache.service"]),
        ]
        set_flag_calls = [mock.call("bcache-tuning.installed")]

        mock_copyfile.assert_has_calls(copyfile_calls)
        mock_chmod.assert_has_calls(chmod_calls)
        mock_check_call.assert_has_calls(checkcall_calls)
        mock_set_flag.assert_has_calls(set_flag_calls)

    @mock.patch.object(bcache_tuning, "status_set")
    def test_assess_status(self, mock_status_set):
        bcache_tuning.assess_status()
        status_set_calls = [mock.call("active", "bcache devices tuned")]
        mock_status_set.assert_has_calls(status_set_calls)
